==> vee_2.4-5.tar.gz: vee-2.4/src/Dialog.py <==
# -*- coding: utf-8 -*-
#    Copyright (C) 2005 Spike^ekipS <spikeekips@gmail.com>
#
#    http://vee.kldp.net
#
#       This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

import gtk
import os, marshal, base64, sre

import WIDGET, child, GConf, Conf, i18n, func

_ = i18n.gettext()

class AskCloseAllTabDialog (WIDGET.WIDGET) :

	GCONF_CLIENT = None
	LIST_TAB = list()
	NOTEBOOK = None
	STATE = None

	def __init__ (self, ROOT, state) :
		handler = { \
			"on_ok"	: self.on_ok, \
			"on_cancel" : self.on_close, \
		}

		WIDGET.WIDGET.__init__( \
			self, "quit", ROOT, handler)

		self.WIDGET_SELF.set_title(_("Quit"))

		self.STATE = state

		if self.STATE.DATA.has_key("tab-list") :
			self.LIST_TAB = self.STATE.DATA["tab-list"]

		if self.STATE.DATA.has_key("notebook") :
			self.NOTEBOOK = self.STATE.DATA["notebook"]

		self.GCONF_CLIENT = GConf.Client()
		self.GCONF_CLIENT.add_dir(Conf.LOCAL_ROOT)

		__label = self.xml.get_widget("label87")
		__label.set_label( \
_("Quit VEE.\nAll the opened tab will be closed."))

	def on_ok (self, widget) :
		self.rememberGeometry()
		#self.removeAllTab()

		gtk.main_quit()

		return True

	def rememberGeometry (self) :
		__is_fullscreened = self.WIDGET_ROOT.get_data("is-fullscreen")

		if __is_fullscreened :
			self.WIDGET_ROOT.unfullscreen()

		# save the latest window geometry.
		__wh = self.GCONF_CLIENT.get_value_by_conf( \
			"latest-window-geometry")
		if len(__wh.split(",")) > 1 :
			__wh0 = [ int(i) for i in __wh.split(",")]
		else :
			__wh0 = (0,0)

		(x, y) = self.WIDGET_ROOT.get_position()

		self.GCONF_CLIENT.set_value_by_conf( \
			"latest-window-geometry", \
			"%d,%d,%d,%d" % (__wh0[0], __wh0[1], x, y) \
		)

		# save the state of fullscreened or not.
		self.GCONF_CLIENT.set_value_by_conf( \
			"is-fullscreen", __is_fullscreened)

	def removeAllTab (self) :
		ALL_REMOVED = True

		# try to close all the tab.
		_n = self.NOTEBOOK.get_n_pages() - 1
		#for i in range(_n) :
		#	try :
		#		ch = self.LIST_TAB[i]
		#	except :
		#		break

		#	try :
		#		exit_method = getattr(ch.Child, "exit")
		#	except AttributeError :
		#		pass
		#	else :
		#		ch.Child.exit()

		#		if not ch.Child.IS_REMOVED :
		#			ALL_REMOVED = False
		#			break

		for i in self.LIST_TAB :
			try :
				exit_method = getattr(ch.Child, "exit")
			except AttributeError :
				pass
			else :
				ch.Child.exit()

				if not ch.Child.IS_REMOVED :
					ALL_REMOVED = False
					break


		if ALL_REMOVED : print "all removed"
		#gtk.main_quit()

class FileSelectionDialog (WIDGET.WIDGET) :

	comboSetChild = "vim"
	CALLBACK_FUNCTIONS = dict()
	STATE = None
	#THEME = None

	NOTEBOOK = None

	CHILD_VIM = 0
	CHILD_GVIM = 1

	PAGE_FILE = 0
	PAGE_DIRECTORY = 1

	LIST_STORED_FILES = list()

	COLOR_WARNING = "#FC4444"

	SRE_FIND_DIRECTORY_SEPARATOR = sre.compile("^[ ][ ]*%s" % os.sep)

	def __init__ (self, **kwargs) :

		if not kwargs.has_key("state") :
			raise ValueError, _("state must be included.")
		else :
			self.STATE = kwargs["state"]

		if not kwargs.has_key("callback_functions") :
			raise ValueError, _("callback_functions must be included.")
		else :
			self.CALLBACK_FUNCTIONS = kwargs["callback_functions"]

		handler = { \
			"on_open"	: self.on_open, \
			"on_cancel" : self.on_close, \
			"on_file_location" : self.on_file_location, \
			"on_directory_location" : self.on_directory_location, \
		}

		WIDGET.WIDGET.__init__( \
			self, "filechooserdialog", None, handler)

		self.GCONF_CLIENT = GConf.Client()
		self.GCONF_CLIENT.add_dir(Conf.LOCAL_ROOT)
		#self.THEME = self.STATE.DATA["theme"]

		self.NOTEBOOK = self.xml.get_widget("notebook")
		self.NOTEBOOK.connect("switch-page", self.on_change_page)

		# get the directory path, which was opened latest.
		__path = self.GCONF_CLIENT.get_value_by_conf( \
			"last-directory-path-in-fileselectdialog")
		if not __path.strip() : __path = os.getenv("HOME")

		self.ChooserFile = self.xml.get_widget("filechooserwidget2")
		self.ChooserDirectory = self.xml.get_widget("filechooserwidget3")

		self.ChooserFile.set_current_folder(__path)

		self.comboSetChild = self.xml.get_widget("combobox2")

		self.comboSetChild.insert_text(self.CHILD_VIM, _("Open In VIM"))
		self.comboSetChild.insert_text(self.CHILD_GVIM, \
			_("Open In GVIM"))
		self.comboSetChild.set_active(self.CHILD_VIM)

		__checkbox_openInThisPage = self.xml.get_widget("checkbutton16")
		__checkbox_openInThisPage.set_label( \
			_("Open this _file(s) in current tab."))

		self.BOX_LAST_FILES = self.xml.get_widget("vbox23")
		self.BOX_LAST_DIRECTORIES = self.xml.get_widget("vbox26")

		__label = self.xml.get_widget("label109")
		__label.set_label(_("Recent Opened Files are,"))
		__label = self.xml.get_widget("label110")
		__label.set_label(_("Recent Opened Directories are,"))
		__label = self.xml.get_widget("label94")
		__label.set_label(_("Select Files"))
		__label = self.xml.get_widget("label95")
		__label.set_label(_("Select Directory"))

		# saved command list.
		EXPANDER = self.xml.get_widget("expander2")
		EXPANDER.connect( \
			"notify::expanded", self.expander_callback_files)

		EXPANDER = self.xml.get_widget("expander3")
		EXPANDER.connect( \
			"notify::expanded", self.expander_callback_directories)

		self.__create_treeview_files()
		self.__create_treeview_directories()

		location_entry_file = self.xml.get_widget("entry19")
		location_entry_file.grab_focus()

	def expander_callback_files (self, expander, param_spec, user_data=None):
		if expander.get_expanded():
			self.BOX_LAST_FILES.show()
			self.WIDGET_SELF.set_property("resizable", True)
		else:
			self.BOX_LAST_FILES.hide()
			#self.WIDGET_SELF.set_property("resizable", False)

	def expander_callback_directories (self, expander, param_spec, user_data=None):
		if expander.get_expanded():
			self.BOX_LAST_DIRECTORIES.show()
			self.WIDGET_SELF.set_property("resizable", True)
		else:
			self.BOX_LAST_DIRECTORIES.hide()
			#self.WIDGET_SELF.set_property("resizable", False)

	def __create_treeview_files (self) :
		self.TREEVIEW_LAST_FILES = self.xml.get_widget("treeview4")
		self.TREEVIEW_LAST_FILES.set_headers_visible(False)

		# connect signal
		self.TREEVIEW_LAST_FILES.connect( \
			"row-activated", self.on_select_command_files)

		# add the cells to the columns - 2 in the first
		cell = gtk.CellRendererText()

		# create a CellRenderers to render the data
		tvcolumn = gtk.TreeViewColumn("", cell, markup=0)
		tvcolumn.set_expand(True)
		tvcolumn.set_sort_column_id(0)
		tvcolumn.pack_start(cell, True)

		self.LISTSTORE_FILES = gtk.ListStore(str)
		self.TREEVIEW_LAST_FILES.set_model(self.LISTSTORE_FILES)
		self.TREEVIEW_LAST_FILES.append_column(tvcolumn)
		self.TREEVIEW_LAST_FILES.set_reorderable(True)

		__data = self.GCONF_CLIENT.get_value_by_conf("recent-opened-files")

		try :
			__data0 = base64.decodestring(__data)
			__data1 = marshal.loads(__data0)

			if type(__data1) is list :
				LIST_STORED_FILES = __data1
		except EOFError :
			pass

		for i in LIST_STORED_FILES :
			if not i.strip() : continue
			self.__append_column_recent_files(i)

	def __append_column_recent_files (self, filename) :
		if not os.path.exists(filename) :
			__d = "<span foreground=\"%s\">%s</span>" % \
				(self.COLOR_WARNING, filename)
		else :
			__d = filename

		self.LISTSTORE_FILES.append([__d,])

	def __create_treeview_directories (self) :
		self.TREEVIEW_LAST_DIRECTORIES = self.xml.get_widget("treeview5")
		self.TREEVIEW_LAST_DIRECTORIES.set_headers_visible(False)

		# connect signal
		self.TREEVIEW_LAST_DIRECTORIES.connect( \
			"row-activated", self.on_select_command_directories)

		# add the cells to the columns - 2 in the first
		cell = gtk.CellRendererText()

		# create a CellRenderers to render the data
		tvcolumn = gtk.TreeViewColumn("", cell, markup=0)
		tvcolumn.set_expand(True)
		tvcolumn.set_sort_column_id(0)
		tvcolumn.pack_start(cell, True)

		self.LISTSTORE_DIRECTORIES = gtk.ListStore(str)
		self.TREEVIEW_LAST_DIRECTORIES.set_model(self.LISTSTORE_DIRECTORIES)
		self.TREEVIEW_LAST_DIRECTORIES.append_column(tvcolumn)
		self.TREEVIEW_LAST_DIRECTORIES.set_reorderable(True)

		__data = self.GCONF_CLIENT.get_value_by_conf( \
			"recent-opened-directories")

		try :
			__data0 = base64.decodestring(__data)
			__data1 = marshal.loads(__data0)

			if type(__data1) is list :
				list_stored = __data1
		except EOFError :
			pass

		for i in list_stored :
			if not i.strip() : continue
			self.__append_column_recent_directory(i)

	def __append_column_recent_directory (self, directory) :
		if not os.path.exists(directory) or \
				not os.path.isdir(directory) :
			__d = "<span foreground=\"%s\">%s</span>" % \
				(self.COLOR_WARNING, directory)
		else :
			__d = directory

		self.LISTSTORE_DIRECTORIES.append([__d,])

	def on_select_command_files (self, widget, path, viewcolumn) :
		__tree_selection = self.TREEVIEW_LAST_FILES.get_selection()
		(__tree_store, __tree_iter) = __tree_selection.get_selected()
		try :
			__value = self.LISTSTORE_FILES.get_value(__tree_iter, 0)
		except TypeError :
			return

		self.__open_files([__value,])

	def on_change_page (self, widget, parm1, page_num) :
		"""
		Notice :
			This code does not operate correctly, i don't know the exact
			reasons.
		"""
		if page_num == 0 :
			location_entry_file = self.xml.get_widget("entry19")
			location_entry_file.grab_focus()
		else :
			location_entry_directory = self.xml.get_widget("entry20")
			location_entry_directory.grab_focus()

	def on_file_location (self, widget, event) :
		if event.keyval != 65293 : return

		__data = widget.get_text()
		if not self.SRE_FIND_DIRECTORY_SEPARATOR.findall(__data.strip()) :
			__data = os.path.join(self.ChooserFile.get_current_folder(), __data)

		__path = func.normalize_path(__data)
		if os.path.isdir(__path) :
			self.ChooserFile.set_current_folder(__path)
			__path = sre.compile( \
				"[%(sep)s][%(sep)s]*$" % {"sep" : sre.escape("%s" % os.sep)} \
			).sub("", __path)
			widget.set_text("%s%s" % (__path, os.sep))
			widget.set_position(len(__path) + 2)
		elif os.path.isfile(__path) :
			self.__open_files([__path,])
		else :
			widget.set_text(__path)
			widget.set_position(len(__path) + 2)
			widget.select_region(0, len(__path) + 2)

		return

	def on_directory_location (self, widget, event) :
		if event.keyval != 65293 : return

		__data = widget.get_text()

		if not self.SRE_FIND_DIRECTORY_SEPARATOR.findall(__data.strip()) :
			__data = os.path.join(self.ChooserDirectory.get_current_folder(), __data)

		__path = func.normalize_path(__data)

		if os.path.isdir(__path) :
			self.ChooserDirectory.set_current_folder(__path)
			__path = sre.compile( \
				"[%(sep)s][%(sep)s]*$" % {"sep" : sre.escape("%s" % os.sep)} \
			).sub("", __path)

			widget.set_text("%s%s" % (__path, os.sep))
			widget.set_position(len(__path) + 2)
		else :
			widget.set_text(__path)
			widget.set_position(len(__path) + 2)
			widget.select_region(0, len(__path) + 2)

		return

	def on_select_command_directories (self, widget, path, viewcolumn) :
		__tree_selection = self.TREEVIEW_LAST_DIRECTORIES.get_selection()
		(__tree_store, __tree_iter) = __tree_selection.get_selected()
		try :
			__value = self.LISTSTORE_DIRECTORIES.get_value(__tree_iter, 0)
		except TypeError :
			return

		self.__open_directory(__value)

	def on_open (self, widget) :
		__current = self.NOTEBOOK.get_current_page()

		if __current == self.PAGE_FILE :
			self.on_open_file()
		elif __current == self.PAGE_DIRECTORY :
			self.on_open_directory()
		else :
			print "What on earth!!!"
			pass

	def on_open_directory (self) :
		__directory = self.ChooserDirectory.get_filename()

		self.__open_directory(__directory)

	def __open_directory (self, directoryname) :

		__func = self.CALLBACK_FUNCTIONS["addPage"]
		__func("terminal", directory=directoryname)
		self.on_close(True)

	def on_open_file (self) :

		file_selected = list()
		if self.ChooserFile.get_select_multiple() :
			file_selected = self.ChooserFile.get_filenames()
		else :
			file_selected.append(self.ChooserFile.get_filename())

		self.__open_files(file_selected)

	def __open_files (self, file_selected=list()) :

		__b = self.xml.get_widget("checkbutton16")
		openInThisPage = __b.get_active()

		# save the current directory to gconf.
		self.GCONF_CLIENT.set_value_by_conf( \
			"last-directory-path-in-fileselectdialog", \
			os.path.dirname(file_selected[0]) \
		)

		__func = self.CALLBACK_FUNCTIONS["addPage"]
		for i in file_selected :
			if os.path.isdir(i) : continue

			if not openInThisPage :
				__type_child = self.comboSetChild.get_active()
				if __type_child == self.CHILD_VIM :
					childname = "vim"
				elif __type_child == self.CHILD_GVIM :
					childname = "gvim"
				else :
					pass

				__func(childname, filename=i)
			else :
				__current_page = \
					self.STATE.DATA["notebook"].get_current_page()

				__child_type = \
					self.STATE.DATA["tab-list"][__current_page].Child.CHILD_TYPE

				if __child_type == child.TYPE_GVIM :
					childname = "gvim"
				elif __child_type == child.TYPE_VIM :
					childname = "vim"
				else :
					pass

				__func( \
					childname, filename=i, openInThisPage=openInThisPage)

		self.on_close(True)

"""
Description
-----------


ChangeLog
---------


Usage
-----


"""

__author__ =  "Spike^ekipS <spikeekips@gmail.com>"
__version__=  "0.1"
__nonsense__ = ""

__file__ = "Dialog.py"

==> vee_2.4-6.tar.gz: vee-2.4/src/Dialog.py <==
# -*- coding: utf-8 -*-
#    Copyright (C) 2005 Spike^ekipS <spikeekips@gmail.com>
#
#    http://vee.kldp.net
#
#       This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

import gtk
import os, marshal, base64, sre

import WIDGET, child, GConf, Conf, i18n, func, Handler

_ = i18n.gettext()

class AskCloseAllTabDialog (WIDGET.WIDGET) :

	GCONF_CLIENT = None
	LIST_TAB = list()
	NOTEBOOK = None
	STATE = None

	def __init__ (self, ROOT, state) :
		WIDGET.WIDGET.__init__( \
			self, "quit", ROOT, dict(), Handler.AskCloseAllTabDialog)

		self.WIDGET_SELF.set_title(_("Quit"))

		self.STATE = state

		if self.STATE.DATA.has_key("tab-list") :
			self.LIST_TAB = self.STATE.DATA["tab-list"]

		if self.STATE.DATA.has_key("notebook") :
			self.NOTEBOOK = self.STATE.DATA["notebook"]

		self.GCONF_CLIENT = GConf.Client()
		self.GCONF_CLIENT.add_dir(Conf.LOCAL_ROOT)

		for i, j in i18n.LABEL_ASKCLOSEALLTABDIALOG.items() :
			self.xml.get_widget(i).set_label(j)

	def on_ok (self, widget) :
		self.rememberGeometry()
		#self.removeAllTab()

		gtk.main_quit()

		return True

	def rememberGeometry (self) :
		__is_fullscreened = self.WIDGET_ROOT.get_data("is-fullscreen")

		if __is_fullscreened :
			self.WIDGET_ROOT.unfullscreen()

		# save the latest window geometry.
		__wh = self.GCONF_CLIENT.get_value_by_conf( \
			"latest-window-geometry")
		if len(__wh.split(",")) > 1 :
			__wh0 = [ int(i) for i in __wh.split(",")]
		else :
			__wh0 = (0,0)

		(x, y) = self.WIDGET_ROOT.get_position()

		self.GCONF_CLIENT.set_value_by_conf( \
			"latest-window-geometry", \
			"%d,%d,%d,%d" % (__wh0[0], __wh0[1], x, y) \
		)

		# save the state of fullscreened or not.
		self.GCONF_CLIENT.set_value_by_conf( \
			"is-fullscreen", __is_fullscreened)

	def removeAllTab (self) :
		ALL_REMOVED = True

		# try to close all the tab.
		_n = self.NOTEBOOK.get_n_pages() - 1
		#for i in range(_n) :
		#	try :
		#		ch = self.LIST_TAB[i]
		#	except :
		#		break

		#	try :
		#		exit_method = getattr(ch.Child, "exit")
		#	except AttributeError :
		#		pass
		#	else :
		#		ch.Child.exit()

		#		if not ch.Child.IS_REMOVED :
		#			ALL_REMOVED = False
		#			break

		for i in self.LIST_TAB :
			try :
				exit_method = getattr(ch.Child, "exit")
			except AttributeError :
				pass
			else :
				ch.Child.exit()

				if not ch.Child.IS_REMOVED :
					ALL_REMOVED = False
					break


		if ALL_REMOVED : print "all removed"
		#gtk.main_quit()

class FileSelectionDialog (WIDGET.WIDGET) :

	comboSetChild = "vim"
	CALLBACK_FUNCTIONS = dict()
	STATE = None
	#THEME = None

	NOTEBOOK = None

	CHILD_VIM = 0
	CHILD_GVIM = 1

	PAGE_FILE = 0
	PAGE_DIRECTORY = 1

	LIST_STORED_FILES = list()

	COLOR_WARNING = "#FC4444"

	SRE_FIND_DIRECTORY_SEPARATOR = sre.compile("^[ ][ ]*%s" % os.sep)

	def __init__ (self, **kwargs) :

		if not kwargs.has_key("state") :
			raise ValueError, _("state must be included.")
		else :
			self.STATE = kwargs["state"]

		if not kwargs.has_key("callback_functions") :
			raise ValueError, _("callback_functions must be included.")
		else :
			self.CALLBACK_FUNCTIONS = kwargs["callback_functions"]

		WIDGET.WIDGET.__init__( \
			self, "filechooserdialog", None, dict(), Handler.FileSelectionDialog)

		self.GCONF_CLIENT = GConf.Client()
		self.GCONF_CLIENT.add_dir(Conf.LOCAL_ROOT)
		#self.THEME = self.STATE.DATA["theme"]

		self.NOTEBOOK = self.xml.get_widget("notebook")
		self.NOTEBOOK.connect("switch-page", self.on_change_page)

		# get the directory path, which was opened latest.
		__path = self.GCONF_CLIENT.get_value_by_conf( \
			"last-directory-path-in-fileselectdialog")
		if not __path.strip() : __path = os.getenv("HOME")

		self.ChooserFile = self.xml.get_widget("filechooserwidget2")
		self.ChooserDirectory = self.xml.get_widget("filechooserwidget3")

		self.ChooserFile.set_current_folder(__path)

		self.comboSetChild = self.xml.get_widget("combobox2")

		self.comboSetChild.insert_text(self.CHILD_VIM, _("Open In VIM"))
		self.comboSetChild.insert_text(self.CHILD_GVIM, \
			_("Open In GVIM"))
		self.comboSetChild.set_active(self.CHILD_VIM)

		__checkbox_openInThisPage = self.xml.get_widget("checkbutton16")

		self.BOX_LAST_FILES = self.xml.get_widget("vbox23")
		self.BOX_LAST_DIRECTORIES = self.xml.get_widget("vbox26")

		for i, j in i18n.LABEL_FILE_CHOOSER.items() :
			self.xml.get_widget(i).set_label(j)

		# saved command list.
		EXPANDER = self.xml.get_widget("expander2")
		EXPANDER.connect( \
			"notify::expanded", self.expander_callback_files)

		EXPANDER = self.xml.get_widget("expander3")
		EXPANDER.connect( \
			"notify::expanded", self.expander_callback_directories)

		self.__create_treeview_files()
		self.__create_treeview_directories()

		location_entry_file = self.xml.get_widget("entry19")
		location_entry_file.grab_focus()

	def expander_callback_files (self, expander, param_spec, user_data=None):
		if expander.get_expanded():
			self.BOX_LAST_FILES.show()
			self.WIDGET_SELF.set_property("resizable", True)
		else:
			self.BOX_LAST_FILES.hide()
			#self.WIDGET_SELF.set_property("resizable", False)

	def expander_callback_directories (self, expander, param_spec, user_data=None):
		if expander.get_expanded():
			self.BOX_LAST_DIRECTORIES.show()
			self.WIDGET_SELF.set_property("resizable", True)
		else:
			self.BOX_LAST_DIRECTORIES.hide()
			#self.WIDGET_SELF.set_property("resizable", False)

	def __create_treeview_files (self) :
		self.TREEVIEW_LAST_FILES = self.xml.get_widget("treeview4")
		self.TREEVIEW_LAST_FILES.set_headers_visible(False)

		# connect signal
		self.TREEVIEW_LAST_FILES.connect( \
			"row-activated", self.on_select_command_files)

		# add the cells to the columns - 2 in the first
		cell = gtk.CellRendererText()

		# create a CellRenderers to render the data
		tvcolumn = gtk.TreeViewColumn("", cell, markup=0)
		tvcolumn.set_expand(True)
		tvcolumn.set_sort_column_id(0)
		tvcolumn.pack_start(cell, True)

		self.LISTSTORE_FILES = gtk.ListStore(str)
		self.TREEVIEW_LAST_FILES.set_model(self.LISTSTORE_FILES)
		self.TREEVIEW_LAST_FILES.append_column(tvcolumn)
		self.TREEVIEW_LAST_FILES.set_reorderable(True)

		__data = self.GCONF_CLIENT.get_value_by_conf("recent-opened-files")

		try :
			__data0 = base64.decodestring(__data)
			__data1 = marshal.loads(__data0)

			if type(__data1) is list :
				LIST_STORED_FILES = __data1
		except EOFError :
			pass

		for i in LIST_STORED_FILES :
			if not i.strip() : continue
			self.__append_column_recent_files(i)

	def __append_column_recent_files (self, filename) :
		if not os.path.exists(filename) :
			__d = "<span foreground=\"%s\">%s</span>" % \
				(self.COLOR_WARNING, filename)
		else :
			__d = filename

		self.LISTSTORE_FILES.append([__d,])

	def __create_treeview_directories (self) :
		self.TREEVIEW_LAST_DIRECTORIES = self.xml.get_widget("treeview5")
		self.TREEVIEW_LAST_DIRECTORIES.set_headers_visible(False)

		# connect signal
		self.TREEVIEW_LAST_DIRECTORIES.connect( \
			"row-activated", self.on_select_command_directories)

		# add the cells to the columns - 2 in the first
		cell = gtk.CellRendererText()

		# create a CellRenderers to render the data
		tvcolumn = gtk.TreeViewColumn("", cell, markup=0)
		tvcolumn.set_expand(True)
		tvcolumn.set_sort_column_id(0)
		tvcolumn.pack_start(cell, True)

		self.LISTSTORE_DIRECTORIES = gtk.ListStore(str)
		self.TREEVIEW_LAST_DIRECTORIES.set_model(self.LISTSTORE_DIRECTORIES)
		self.TREEVIEW_LAST_DIRECTORIES.append_column(tvcolumn)
		self.TREEVIEW_LAST_DIRECTORIES.set_reorderable(True)

		__data = self.GCONF_CLIENT.get_value_by_conf( \
			"recent-opened-directories")

		try :
			__data0 = base64.decodestring(__data)
			__data1 = marshal.loads(__data0)

			if type(__data1) is list :
				list_stored = __data1
		except EOFError :
			pass

		for i in list_stored :
			if not i.strip() : continue
			self.__append_column_recent_directory(i)

	def __append_column_recent_directory (self, directory) :
		if not os.path.exists(directory) or \
				not os.path.isdir(directory) :
			__d = "<span foreground=\"%s\">%s</span>" % \
				(self.COLOR_WARNING, directory)
		else :
			__d = directory

		self.LISTSTORE_DIRECTORIES.append([__d,])

	def on_select_command_files (self, widget, path, viewcolumn) :
		__tree_selection = self.TREEVIEW_LAST_FILES.get_selection()
		(__tree_store, __tree_iter) = __tree_selection.get_selected()
		try :
			__value = self.LISTSTORE_FILES.get_value(__tree_iter, 0)
		except TypeError :
			return

		self.__open_files([__value,])

	def on_change_page (self, widget, parm1, page_num) :
		"""
		Notice :
			This code does not operate correctly, i don't know the exact
			reasons.
		"""
		if page_num == 0 :
			location_entry_file = self.xml.get_widget("entry19")
			location_entry_file.grab_focus()
		else :
			location_entry_directory = self.xml.get_widget("entry20")
			location_entry_directory.grab_focus()

	def on_file_location (self, widget, event) :
		if event.keyval != 65293 : return

		__data = widget.get_text()
		if not self.SRE_FIND_DIRECTORY_SEPARATOR.findall(__data.strip()) :
			__data = os.path.join(self.ChooserFile.get_current_folder(), __data)

		__path = func.normalize_path(__data)
		if os.path.isdir(__path) :
			self.ChooserFile.set_current_folder(__path)
			__path = sre.compile( \
				"[%(sep)s][%(sep)s]*$" % {"sep" : sre.escape("%s" % os.sep)} \
			).sub("", __path)
			widget.set_text("%s%s" % (__path, os.sep))
			widget.set_position(len(__path) + 2)
		elif os.path.isfile(__path) :
			self.__open_files([__path,])
		else :
			widget.set_text(__path)
			widget.set_position(len(__path) + 2)
			widget.select_region(0, len(__path) + 2)

		return

	def on_directory_location (self, widget, event) :
		if event.keyval != 65293 : return

		__data = widget.get_text()

		if not self.SRE_FIND_DIRECTORY_SEPARATOR.findall(__data.strip()) :
			__data = os.path.join(self.ChooserDirectory.get_current_folder(), __data)

		__path = func.normalize_path(__data)

		if os.path.isdir(__path) :
			self.ChooserDirectory.set_current_folder(__path)
			__path = sre.compile( \
				"[%(sep)s][%(sep)s]*$" % {"sep" : sre.escape("%s" % os.sep)} \
			).sub("", __path)

			widget.set_text("%s%s" % (__path, os.sep))
			widget.set_position(len(__path) + 2)
		else :
			widget.set_text(__path)
			widget.set_position(len(__path) + 2)
			widget.select_region(0, len(__path) + 2)

		return

	def on_select_command_directories (self, widget, path, viewcolumn) :
		__tree_selection = self.TREEVIEW_LAST_DIRECTORIES.get_selection()
		(__tree_store, __tree_iter) = __tree_selection.get_selected()
		try :
			__value = self.LISTSTORE_DIRECTORIES.get_value(__tree_iter, 0)
		except TypeError :
			return

		self.__open_directory(__value)

	def on_open (self, widget) :
		__current = self.NOTEBOOK.get_current_page()

		if __current == self.PAGE_FILE :
			self.on_open_file()
		elif __current == self.PAGE_DIRECTORY :
			self.on_open_directory()
		else :
			print "What on earth!!!"
			pass

	def on_open_directory (self) :
		__directory = self.ChooserDirectory.get_filename()

		self.__open_directory(__directory)

	def __open_directory (self, directoryname) :

		__func = self.CALLBACK_FUNCTIONS["addPage"]
		__func("terminal", directory=directoryname)
		self.on_close(True)

	def on_open_file (self) :

		file_selected = list()
		if self.ChooserFile.get_select_multiple() :
			file_selected = self.ChooserFile.get_filenames()
		else :
			file_selected.append(self.ChooserFile.get_filename())

		self.__open_files(file_selected)

	def __open_files (self, file_selected=list()) :

		__b = self.xml.get_widget("checkbutton16")
		openInThisPage = __b.get_active()

		# save the current directory to gconf.
		self.GCONF_CLIENT.set_value_by_conf( \
			"last-directory-path-in-fileselectdialog", \
			os.path.dirname(file_selected[0]) \
		)

		__func = self.CALLBACK_FUNCTIONS["addPage"]
		for i in file_selected :
			if os.path.isdir(i) : continue

			if not openInThisPage :
				__type_child = self.comboSetChild.get_active()
				if __type_child == self.CHILD_VIM :
					childname = "vim"
				elif __type_child == self.CHILD_GVIM :
					childname = "gvim"
				else :
					pass

				__func(childname, filename=i)
			else :
				__current_page = \
					self.STATE.DATA["notebook"].get_current_page()

				__child_type = \
					self.STATE.DATA["tab-list"][__current_page].Child.CHILD_TYPE

				if __child_type == child.TYPE_GVIM :
					childname = "gvim"
				elif __child_type == child.TYPE_VIM :
					childname = "vim"
				else :
					pass

				__func( \
					childname, filename=i, openInThisPage=openInThisPage)

		self.on_close(True)

"""
Description
-----------


ChangeLog
---------


Usage
-----


"""

__author__ =  "Spike^ekipS <spikeekips@gmail.com>"
__version__=  "0.1"
__nonsense__ = ""

__file__ = "Dialog.py"
